@@ -9,7 +9,7 @@ from xllabelme.logger import logger
 import xllabelme.utils
 from xllabelme.shape import Shape
 
-from pyxllib.extend.qt import get_input_widget, QHLine
+from pyxllib.ext.qt import get_input_widget, QHLine
 
 QT5 = QT_VERSION[0] == "5"
 
